package types

type Text struct {
	Text string `yaml:"text"`
	Id   string `yaml:"id"`
}

type Image struct {
	Id     string `yaml:"id"`
	Source string `yaml:"source"`
	Alt    string `yaml:"alt"`
	Title  string `yaml:"title"`
}

type Anchor struct {
	Id       string `yaml:"id"`
	Href     string `yaml:"href"`
	HrefLang string `yaml:"hreflang"`
	Title    string `yaml:"title"`
}

type Translations struct {
	Id        string         `yaml:"id"`
	Type      string         `yaml:"type"`
	KeyValues map[string]any `yaml:"translations"`
}

type AddModification struct {
	Selector string `yaml:"selector"`
	Html     string `yaml:"html"`
}

type SetAttributeModification struct {
	Selector string `yaml:"selector"`
	Name     string `yaml:"name"`
	Value    string `yaml:"value"`
}

type Modifications struct {
	Remove       []string                   `yaml:"remove"`
	Add          []AddModification          `yaml:"add"`
	SetAttribute []SetAttributeModification `yaml:"attributes"`
}

type PageData struct {
	Export        string            `yaml:"export"`
	Lang          string            `yaml:"lang"`
	Title         string            `yaml:"title"`
	Meta          map[string]string `yaml:"meta"`
	Images        []Image           `yaml:"images"`
	Anchors       []Anchor          `yaml:"anchors"`
	Text          []Text            `yaml:"text"`
	Translations  []Translations    `yaml:"translations"`
	Modifications Modifications     `yaml:"modifications"`
}

func NewPageData() *PageData {
	pd := &PageData{}
	pd.Meta = make(map[string]string)
	return pd
}

type PageDataStorage map[string]*PageData

func NewPageDataStorage() PageDataStorage {
	var storage PageDataStorage
	storage = PageDataStorage{}
	return storage

}

func (p *PageDataStorage) ResetContent() {
	for _, pageData := range *p {
		pageData.ResetContent()
	}
}

func (p *PageData) ResetContent() {

	p.Title = ""
	p.Meta = make(map[string]string)
	p.Images = make([]Image, 0)
	p.Anchors = make([]Anchor, 0)
	p.Text = make([]Text, 0)
	p.Translations = make([]Translations, 0)

}
