{pkgs, ...}: ''

  if [ -t 1 ]; then
      RED='\033[0;31m'
      GREEN='\033[0;32m'
      BLUE='\033[0;34m'
      RESET='\033[0m'
      BOLD='\033[1m'
  else
      RED=""
      GREEN=""
      BLUE=""
      RESET=""
  fi

  is_true() {
      val="$1"
      if [ "$val" = 'true' ] || [ "$val" = '1' ]; then
          return 0
      else
          return 1
      fi
  }

  CURRENT_LEVEL=0

  get_padding() {
      local padding=""
      for ((i=0; i < CURRENT_LEVEL; i++)); do
          padding+="  "
      done
      echo "$padding"
  }

  increase_level() {
      CURRENT_LEVEL=$((CURRENT_LEVEL + 1))
  }

  decrease_level() {
      CURRENT_LEVEL=$((CURRENT_LEVEL - 1))
  }

  echo_header() {
      decrease_level
      padding=$(get_padding)
      ${pkgs.figlet}/bin/figlet -f doom -c "$1"
      increase_level
  }

  echo_ok() {
      padding=$(get_padding)
      echo -e "$padding$GREEN✔$RESET $1"
  }

  echo_delimiter() {
      echo " "
  }

  echo_section() {
      decrease_level
      padding=$(get_padding)
      echo -e "\n\n$padding$BOLD$1$RESET"
      increase_level
  }

  echo_text() {
      padding=$(get_padding)
      echo -e "$padding$1"
  }

  echo_fail() {
      padding=$(get_padding)
      echo -e "$padding$RED✖ $1$RESET"
  }

  echo_hint() {
      padding=$(get_padding)
      echo -e "$padding$BLUE→ $1$RESET"
  }

  echo_step() {
      padding=$(get_padding)
      echo -e "$padding$BLUE•$RESET $1"
  }

  convert_multiline_for_nix() {
     printf "%s" "
     }$1" | ${pkgs.gnused}/bin/sed 's/\\/\\\\/g; s/"/\\"/g; s/$/\\n/g' | tr -d '\n'
  }

  if [ -z "$DEBUG_MODE" ]; then
      DEBUG_MODE='false'
  fi

  if [ -n "$CI_JOB_TOKEN" ]; then
      CI_MODE='true'
  fi

  if is_true "$DEBUG_MODE" || is_true "$CI_MODE"; then
      set -x
  fi
''
